https://github.com/python/cpython/commit/36e4ffc1731fc939fde83a62ed547e81e94961af
commit: 36e4ffc1731fc939fde83a62ed547e81e94961af
branch: main
author: Russell Keith-Magee <[email protected]>
committer: freakboy3742 <[email protected]>
date: 2026-03-27T02:50:35Z
summary:

gh-146444: Move the Apple folder to the Platforms directory (#146497)

Migrate the Apple/iOS XCframework build tools to the Platforms directory.

files:
A Misc/NEWS.d/next/Build/2026-03-26-12-27-42.gh-issue-146444.JKJuEa.rst
A Platforms/Apple/.ruff.toml
A Platforms/Apple/__main__.py
A Platforms/Apple/iOS/README.md
A Platforms/Apple/iOS/Resources/Info.plist.in
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-ar
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-clang
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-clang++
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-cpp
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-ar
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang++
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-cpp
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-strip
A Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-strip
A Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-ar
A Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang
A Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang++
A Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-cpp
A Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-strip
A Platforms/Apple/iOS/Resources/pyconfig.h
A Platforms/Apple/testbed/Python.xcframework/Info.plist
A Platforms/Apple/testbed/Python.xcframework/build/iOS-dylib-Info-template.plist
A Platforms/Apple/testbed/Python.xcframework/build/utils.sh
A Platforms/Apple/testbed/Python.xcframework/ios-arm64/README
A Platforms/Apple/testbed/Python.xcframework/ios-arm64_x86_64-simulator/README
A Platforms/Apple/testbed/Testbed.lldbinit
A Platforms/Apple/testbed/TestbedTests/TestbedTests.m
A Platforms/Apple/testbed/__main__.py
A Platforms/Apple/testbed/iOSTestbed.xcodeproj/project.pbxproj
A 
Platforms/Apple/testbed/iOSTestbed.xcodeproj/xcshareddata/xcschemes/iOSTestbed.xcscheme
A Platforms/Apple/testbed/iOSTestbed.xctestplan
A Platforms/Apple/testbed/iOSTestbed/AppDelegate.h
A Platforms/Apple/testbed/iOSTestbed/AppDelegate.m
A 
Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/AccentColor.colorset/Contents.json
A 
Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/AppIcon.appiconset/Contents.json
A Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/Contents.json
A Platforms/Apple/testbed/iOSTestbed/Base.lproj/LaunchScreen.storyboard
A Platforms/Apple/testbed/iOSTestbed/app/README
A Platforms/Apple/testbed/iOSTestbed/app_packages/README
A Platforms/Apple/testbed/iOSTestbed/iOSTestbed-Info.plist
A Platforms/Apple/testbed/iOSTestbed/main.m
D Apple/.ruff.toml
D Apple/__main__.py
D Apple/iOS/README.md
D Apple/iOS/Resources/Info.plist.in
D Apple/iOS/Resources/bin/arm64-apple-ios-ar
D Apple/iOS/Resources/bin/arm64-apple-ios-clang
D Apple/iOS/Resources/bin/arm64-apple-ios-clang++
D Apple/iOS/Resources/bin/arm64-apple-ios-cpp
D Apple/iOS/Resources/bin/arm64-apple-ios-simulator-ar
D Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang
D Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang++
D Apple/iOS/Resources/bin/arm64-apple-ios-simulator-cpp
D Apple/iOS/Resources/bin/arm64-apple-ios-simulator-strip
D Apple/iOS/Resources/bin/arm64-apple-ios-strip
D Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-ar
D Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang
D Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang++
D Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-cpp
D Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-strip
D Apple/iOS/Resources/pyconfig.h
D Apple/testbed/Python.xcframework/Info.plist
D Apple/testbed/Python.xcframework/build/iOS-dylib-Info-template.plist
D Apple/testbed/Python.xcframework/build/utils.sh
D Apple/testbed/Python.xcframework/ios-arm64/README
D Apple/testbed/Python.xcframework/ios-arm64_x86_64-simulator/README
D Apple/testbed/Testbed.lldbinit
D Apple/testbed/TestbedTests/TestbedTests.m
D Apple/testbed/__main__.py
D Apple/testbed/iOSTestbed.xcodeproj/project.pbxproj
D Apple/testbed/iOSTestbed.xcodeproj/xcshareddata/xcschemes/iOSTestbed.xcscheme
D Apple/testbed/iOSTestbed.xctestplan
D Apple/testbed/iOSTestbed/AppDelegate.h
D Apple/testbed/iOSTestbed/AppDelegate.m
D Apple/testbed/iOSTestbed/Assets.xcassets/AccentColor.colorset/Contents.json
D Apple/testbed/iOSTestbed/Assets.xcassets/AppIcon.appiconset/Contents.json
D Apple/testbed/iOSTestbed/Assets.xcassets/Contents.json
D Apple/testbed/iOSTestbed/Base.lproj/LaunchScreen.storyboard
D Apple/testbed/iOSTestbed/app/README
D Apple/testbed/iOSTestbed/app_packages/README
D Apple/testbed/iOSTestbed/iOSTestbed-Info.plist
D Apple/testbed/iOSTestbed/main.m
M .github/workflows/build.yml
M .pre-commit-config.yaml
M Makefile.pre.in
M configure
M configure.ac

diff --git a/.github/workflows/build.yml b/.github/workflows/build.yml
index 3a6d6a763f2c9c..f8ce2d684604e0 100644
--- a/.github/workflows/build.yml
+++ b/.github/workflows/build.yml
@@ -369,7 +369,7 @@ jobs:
           sudo xcode-select --switch /Applications/Xcode_15.4.app
 
       - name: Build and test
-        run: python3 Apple ci iOS --fast-ci --simulator 'iPhone SE (3rd 
generation),OS=17.5'
+        run: python3 Platforms/Apple ci iOS --fast-ci --simulator 'iPhone SE 
(3rd generation),OS=17.5'
 
   build-emscripten:
     name: 'Emscripten'
diff --git a/.pre-commit-config.yaml b/.pre-commit-config.yaml
index dfd18182105e11..6e612ce232fb29 100644
--- a/.pre-commit-config.yaml
+++ b/.pre-commit-config.yaml
@@ -3,9 +3,9 @@ repos:
     rev: a27a2e47c7751b639d2b5badf0ef6ff11fee893f  # frozen: v0.15.4
     hooks:
       - id: ruff-check
-        name: Run Ruff (lint) on Apple/
-        args: [--exit-non-zero-on-fix, --config=Apple/.ruff.toml]
-        files: ^Apple/
+        name: Run Ruff (lint) on Platforms/Apple/
+        args: [--exit-non-zero-on-fix, --config=Platforms/Apple/.ruff.toml]
+        files: ^Platforms/Apple/
       - id: ruff-check
         name: Run Ruff (lint) on Doc/
         args: [--exit-non-zero-on-fix]
@@ -39,9 +39,9 @@ repos:
         args: [--exit-non-zero-on-fix, --config=Tools/wasm/.ruff.toml]
         files: ^Tools/wasm/
       - id: ruff-format
-        name: Run Ruff (format) on Apple/
-        args: [--exit-non-zero-on-fix, --config=Apple/.ruff.toml]
-        files: ^Apple
+        name: Run Ruff (format) on Platforms/Apple/
+        args: [--exit-non-zero-on-fix, --config=Platforms/Apple/.ruff.toml]
+        files: ^Platforms/Apple/
       - id: ruff-format
         name: Run Ruff (format) on Doc/
         args: [--exit-non-zero-on-fix]
diff --git a/Makefile.pre.in b/Makefile.pre.in
index 1a4755f3bf62ea..354580aa482d25 100644
--- a/Makefile.pre.in
+++ b/Makefile.pre.in
@@ -2358,7 +2358,7 @@ testios:
        fi
 
        # Clone the testbed project into the XCFOLDER
-       $(PYTHON_FOR_BUILD) $(srcdir)/Apple/testbed clone --framework 
$(PYTHONFRAMEWORKPREFIX) "$(XCFOLDER)"
+       $(PYTHON_FOR_BUILD) $(srcdir)/Platforms/Apple/testbed clone --framework 
$(PYTHONFRAMEWORKPREFIX) "$(XCFOLDER)"
 
        # Run the testbed project
        $(PYTHON_FOR_BUILD) "$(XCFOLDER)" run --verbose -- test -uall 
--single-process --rerun -W --pythoninfo
@@ -3286,10 +3286,10 @@ clean-retain-profile: pycremoval
        -find build -type f -a ! -name '*.gc??' -exec rm -f {} ';'
        -rm -f Include/pydtrace_probes.h
        -rm -f profile-gen-stamp
-       -rm -rf Apple/iOS/testbed/Python.xcframework/ios-*/bin
-       -rm -rf Apple/iOS/testbed/Python.xcframework/ios-*/lib
-       -rm -rf Apple/iOS/testbed/Python.xcframework/ios-*/include
-       -rm -rf Apple/iOS/testbed/Python.xcframework/ios-*/Python.framework
+       -rm -rf Platforms/Apple/iOS/testbed/Python.xcframework/ios-*/bin
+       -rm -rf Platforms/Apple/iOS/testbed/Python.xcframework/ios-*/lib
+       -rm -rf Platforms/Apple/iOS/testbed/Python.xcframework/ios-*/include
+       -rm -rf 
Platforms/Apple/iOS/testbed/Python.xcframework/ios-*/Python.framework
 
 .PHONY: profile-removal
 profile-removal:
@@ -3323,7 +3323,7 @@ clobber: clean
                config.cache config.log pyconfig.h Modules/config.c
        -rm -rf build platform
        -rm -rf $(PYTHONFRAMEWORKDIR)
-       -rm -rf Apple/iOS/Frameworks
+       -rm -rf Platforms/Apple/iOS/Frameworks
        -rm -rf iOSTestbed.*
        -rm -f python-config.py python-config
        -rm -rf cross-build
diff --git 
a/Misc/NEWS.d/next/Build/2026-03-26-12-27-42.gh-issue-146444.JKJuEa.rst 
b/Misc/NEWS.d/next/Build/2026-03-26-12-27-42.gh-issue-146444.JKJuEa.rst
new file mode 100644
index 00000000000000..40489f41a2ad6a
--- /dev/null
+++ b/Misc/NEWS.d/next/Build/2026-03-26-12-27-42.gh-issue-146444.JKJuEa.rst
@@ -0,0 +1 @@
+The Apple/iOS build script has been moved to the Platforms directory.
diff --git a/Apple/.ruff.toml b/Platforms/Apple/.ruff.toml
similarity index 88%
rename from Apple/.ruff.toml
rename to Platforms/Apple/.ruff.toml
index 4cdc39ebee4be9..f5d74fdb6afe87 100644
--- a/Apple/.ruff.toml
+++ b/Platforms/Apple/.ruff.toml
@@ -1,4 +1,4 @@
-extend = "../.ruff.toml"  # Inherit the project-wide settings
+extend = "../../.ruff.toml"  # Inherit the project-wide settings
 
 [format]
 preview = true
diff --git a/Apple/iOS/README.md b/Platforms/Apple/iOS/README.md
similarity index 92%
rename from Apple/iOS/README.md
rename to Platforms/Apple/iOS/README.md
index 7ee257b5d648f4..faeeead1df03a2 100644
--- a/Apple/iOS/README.md
+++ b/Platforms/Apple/iOS/README.md
@@ -52,11 +52,11 @@ portable to machines using other architectures.
 
 ### Building a multi-architecture iOS XCframework
 
-The `Apple` subfolder of the Python repository acts as a build script that
+The `Platforms/Apple` subfolder of the Python repository acts as a build 
script that
 can be used to coordinate the compilation of a complete iOS XCframework. To use
 it, run::
 
-  python Apple build iOS
+  python Platforms/Apple build iOS
 
 This will:
 
@@ -69,7 +69,7 @@ This will:
   the `Python.xcframework`, plus a copy of the Testbed app pre-configured to
   use the XCframework.
 
-The `Apple` build script has other entry points that will perform the
+The `Platforms/Apple` build script has other entry points that will perform the
 individual parts of the overall `build` target, plus targets to test the
 build, clean the `cross-build` folder of iOS build products, and perform a
 complete "build and test" CI run. The `--clean` flag can also be used on
@@ -78,7 +78,7 @@ building.
 
 ### Building a single-architecture framework
 
-If you're using the `Apple` build script, you won't need to build
+If you're using the `Platforms/Apple` build script, you won't need to build
 individual frameworks. However, if you do need to manually configure an iOS
 Python build for a single framework, the following options are available.
 
@@ -100,7 +100,7 @@ Python build for a single framework, the following options 
are available.
   > [!NOTE]
   > Unless you know what you're doing, changing the name of the Python
   > framework on iOS is not advised. If you use this option, you won't be able
-  > to run the `Apple` build script without making significant manual
+  > to run the `Platforms/Apple` build script without making significant manual
   > alterations, and you won't be able to use any binary packages unless you
   > compile them yourself using your own framework name.
 
@@ -119,7 +119,7 @@ provide the `--enable-framework` flag when configuring the 
build. The build
 also requires the use of cross-compilation. The minimal commands for building
 Python for the ARM64 iOS simulator will look something like:
 ```
-export 
PATH="$(pwd)/Apple/iOS/Resources/bin:/usr/bin:/bin:/usr/sbin:/sbin:/Library/Apple/usr/bin"
+export 
PATH="$(pwd)/Platforms/Apple/iOS/Resources/bin:/usr/bin:/bin:/usr/sbin:/sbin:/Library/Apple/usr/bin"
 ./configure \
     --enable-framework \
     --host=arm64-apple-ios-simulator \
@@ -131,7 +131,7 @@ make install
 
 In this invocation:
 
-* `Apple/iOS/Resources/bin` has been added to the path, providing some shims 
for the
+* `Platforms/Apple/iOS/Resources/bin` has been added to the path, providing 
some shims for the
   compilers and linkers needed by the build. Xcode requires the use of `xcrun`
   to invoke compiler tooling. However, if `xcrun` is pre-evaluated and the
   result passed to `configure`, these results can embed user- and
@@ -141,7 +141,7 @@ In this invocation:
   cause significant problems with many C configuration systems which assume 
that
   `CC` will be a single executable.
 
-  To work around this problem, the `Apple/iOS/Resources/bin` folder contains 
some
+  To work around this problem, the `Platforms/Apple/iOS/Resources/bin` folder 
contains some
   wrapper scripts that present as simple compilers and linkers, but wrap
   underlying calls to `xcrun`. This allows configure to use a `CC`
   definition without spaces, and without user- or version-specific paths, while
@@ -222,7 +222,7 @@ simulator build with a deployment target of 15.4.
 
 Once you have a built an XCframework, you can test that framework by running:
 
-  $ python Apple test iOS
+  $ python Platforms/Apple test iOS
 
 This test will attempt to find an "SE-class" simulator (i.e., an iPhone SE, or
 iPhone 16e, or similar), and run the test suite on the most recent version of
@@ -237,7 +237,7 @@ environment variable will be exposed to the iOS process at 
runtime.
 
 ### Testing a single-architecture framework
 
-The `Apple/testbed` folder that contains an Xcode project that is able to run
+The `Platforms/Apple/testbed` folder that contains an Xcode project that is 
able to run
 the Python test suite on Apple platforms. This project converts the Python test
 suite into a single test case in Xcode's XCTest framework. The single XCTest
 passes if the test suite passes.
@@ -245,7 +245,7 @@ passes if the test suite passes.
 To run the test suite, configure a Python build for an iOS simulator (i.e.,
 `--host=arm64-apple-ios-simulator` or `--host=x86_64-apple-ios-simulator`
 ), specifying a framework build (i.e. `--enable-framework`). Ensure that your
-`PATH` has been configured to include the `Apple/iOS/Resources/bin` folder and
+`PATH` has been configured to include the `Platforms/Apple/iOS/Resources/bin` 
folder and
 exclude any non-iOS tools, then run:
 ```
 make all
@@ -269,9 +269,9 @@ project, and then boot and prepare the iOS simulator.
 
 ### Debugging test failures
 
-Running `python Apple test iOS` generates a standalone version of the
-`Apple/testbed` project, and runs the full test suite. It does this using
-`Apple/testbed` itself - the folder is an executable module that can be used
+Running `python Platforms/Apple test iOS` generates a standalone version of the
+`Platforms/Apple/testbed` project, and runs the full test suite. It does this 
using
+`Platforms/Apple/testbed` itself - the folder is an executable module that can 
be used
 to create and run a clone of the testbed project. The standalone version of the
 testbed will be created in a directory named
 `cross-build/iOS-testbed.<timestamp>`.
@@ -287,7 +287,7 @@ testbed clone.
 If you've built your own XCframework, or you only want to test a single 
architecture,
 you can construct a standalone testbed instance by running:
 ```
-python Apple/testbed clone --platform iOS --framework <path/to/framework> 
my-testbed
+python Platforms/Apple/testbed clone --platform iOS --framework 
<path/to/framework> my-testbed
 ```
 
 The framework path can be the path path to a `Python.xcframework`, or the
diff --git a/Apple/iOS/Resources/Info.plist.in 
b/Platforms/Apple/iOS/Resources/Info.plist.in
similarity index 100%
rename from Apple/iOS/Resources/Info.plist.in
rename to Platforms/Apple/iOS/Resources/Info.plist.in
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-ar 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-ar
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-ar
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-ar
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-clang 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-clang
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-clang
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-clang
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-clang++ 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-clang++
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-clang++
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-clang++
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-cpp 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-cpp
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-cpp
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-cpp
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-ar 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-ar
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-simulator-ar
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-ar
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang++ 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang++
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang++
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-clang++
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-cpp 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-cpp
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-simulator-cpp
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-cpp
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-strip 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-strip
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-simulator-strip
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-simulator-strip
diff --git a/Apple/iOS/Resources/bin/arm64-apple-ios-strip 
b/Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-strip
similarity index 100%
rename from Apple/iOS/Resources/bin/arm64-apple-ios-strip
rename to Platforms/Apple/iOS/Resources/bin/arm64-apple-ios-strip
diff --git a/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-ar 
b/Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-ar
similarity index 100%
rename from Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-ar
rename to Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-ar
diff --git a/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang 
b/Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang
similarity index 100%
rename from Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang
rename to Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang
diff --git a/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang++ 
b/Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang++
similarity index 100%
rename from Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang++
rename to Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-clang++
diff --git a/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-cpp 
b/Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-cpp
similarity index 100%
rename from Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-cpp
rename to Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-cpp
diff --git a/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-strip 
b/Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-strip
similarity index 100%
rename from Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-strip
rename to Platforms/Apple/iOS/Resources/bin/x86_64-apple-ios-simulator-strip
diff --git a/Apple/iOS/Resources/pyconfig.h 
b/Platforms/Apple/iOS/Resources/pyconfig.h
similarity index 100%
rename from Apple/iOS/Resources/pyconfig.h
rename to Platforms/Apple/iOS/Resources/pyconfig.h
diff --git a/Apple/testbed/Python.xcframework/Info.plist 
b/Platforms/Apple/testbed/Python.xcframework/Info.plist
similarity index 100%
rename from Apple/testbed/Python.xcframework/Info.plist
rename to Platforms/Apple/testbed/Python.xcframework/Info.plist
diff --git 
a/Apple/testbed/Python.xcframework/build/iOS-dylib-Info-template.plist 
b/Platforms/Apple/testbed/Python.xcframework/build/iOS-dylib-Info-template.plist
similarity index 100%
rename from Apple/testbed/Python.xcframework/build/iOS-dylib-Info-template.plist
rename to 
Platforms/Apple/testbed/Python.xcframework/build/iOS-dylib-Info-template.plist
diff --git a/Apple/testbed/Python.xcframework/build/utils.sh 
b/Platforms/Apple/testbed/Python.xcframework/build/utils.sh
similarity index 100%
rename from Apple/testbed/Python.xcframework/build/utils.sh
rename to Platforms/Apple/testbed/Python.xcframework/build/utils.sh
diff --git a/Apple/testbed/Python.xcframework/ios-arm64/README 
b/Platforms/Apple/testbed/Python.xcframework/ios-arm64/README
similarity index 100%
rename from Apple/testbed/Python.xcframework/ios-arm64/README
rename to Platforms/Apple/testbed/Python.xcframework/ios-arm64/README
diff --git a/Apple/testbed/Python.xcframework/ios-arm64_x86_64-simulator/README 
b/Platforms/Apple/testbed/Python.xcframework/ios-arm64_x86_64-simulator/README
similarity index 100%
rename from Apple/testbed/Python.xcframework/ios-arm64_x86_64-simulator/README
rename to 
Platforms/Apple/testbed/Python.xcframework/ios-arm64_x86_64-simulator/README
diff --git a/Apple/testbed/Testbed.lldbinit 
b/Platforms/Apple/testbed/Testbed.lldbinit
similarity index 100%
rename from Apple/testbed/Testbed.lldbinit
rename to Platforms/Apple/testbed/Testbed.lldbinit
diff --git a/Apple/testbed/TestbedTests/TestbedTests.m 
b/Platforms/Apple/testbed/TestbedTests/TestbedTests.m
similarity index 100%
rename from Apple/testbed/TestbedTests/TestbedTests.m
rename to Platforms/Apple/testbed/TestbedTests/TestbedTests.m
diff --git a/Apple/testbed/__main__.py b/Platforms/Apple/testbed/__main__.py
similarity index 100%
rename from Apple/testbed/__main__.py
rename to Platforms/Apple/testbed/__main__.py
diff --git a/Apple/testbed/iOSTestbed.xcodeproj/project.pbxproj 
b/Platforms/Apple/testbed/iOSTestbed.xcodeproj/project.pbxproj
similarity index 100%
rename from Apple/testbed/iOSTestbed.xcodeproj/project.pbxproj
rename to Platforms/Apple/testbed/iOSTestbed.xcodeproj/project.pbxproj
diff --git 
a/Apple/testbed/iOSTestbed.xcodeproj/xcshareddata/xcschemes/iOSTestbed.xcscheme 
b/Platforms/Apple/testbed/iOSTestbed.xcodeproj/xcshareddata/xcschemes/iOSTestbed.xcscheme
similarity index 100%
rename from 
Apple/testbed/iOSTestbed.xcodeproj/xcshareddata/xcschemes/iOSTestbed.xcscheme
rename to 
Platforms/Apple/testbed/iOSTestbed.xcodeproj/xcshareddata/xcschemes/iOSTestbed.xcscheme
diff --git a/Apple/testbed/iOSTestbed.xctestplan 
b/Platforms/Apple/testbed/iOSTestbed.xctestplan
similarity index 100%
rename from Apple/testbed/iOSTestbed.xctestplan
rename to Platforms/Apple/testbed/iOSTestbed.xctestplan
diff --git a/Apple/testbed/iOSTestbed/AppDelegate.h 
b/Platforms/Apple/testbed/iOSTestbed/AppDelegate.h
similarity index 100%
rename from Apple/testbed/iOSTestbed/AppDelegate.h
rename to Platforms/Apple/testbed/iOSTestbed/AppDelegate.h
diff --git a/Apple/testbed/iOSTestbed/AppDelegate.m 
b/Platforms/Apple/testbed/iOSTestbed/AppDelegate.m
similarity index 100%
rename from Apple/testbed/iOSTestbed/AppDelegate.m
rename to Platforms/Apple/testbed/iOSTestbed/AppDelegate.m
diff --git 
a/Apple/testbed/iOSTestbed/Assets.xcassets/AccentColor.colorset/Contents.json 
b/Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/AccentColor.colorset/Contents.json
similarity index 100%
rename from 
Apple/testbed/iOSTestbed/Assets.xcassets/AccentColor.colorset/Contents.json
rename to 
Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/AccentColor.colorset/Contents.json
diff --git 
a/Apple/testbed/iOSTestbed/Assets.xcassets/AppIcon.appiconset/Contents.json 
b/Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/AppIcon.appiconset/Contents.json
similarity index 100%
rename from 
Apple/testbed/iOSTestbed/Assets.xcassets/AppIcon.appiconset/Contents.json
rename to 
Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/AppIcon.appiconset/Contents.json
diff --git a/Apple/testbed/iOSTestbed/Assets.xcassets/Contents.json 
b/Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/Contents.json
similarity index 100%
rename from Apple/testbed/iOSTestbed/Assets.xcassets/Contents.json
rename to Platforms/Apple/testbed/iOSTestbed/Assets.xcassets/Contents.json
diff --git a/Apple/testbed/iOSTestbed/Base.lproj/LaunchScreen.storyboard 
b/Platforms/Apple/testbed/iOSTestbed/Base.lproj/LaunchScreen.storyboard
similarity index 100%
rename from Apple/testbed/iOSTestbed/Base.lproj/LaunchScreen.storyboard
rename to Platforms/Apple/testbed/iOSTestbed/Base.lproj/LaunchScreen.storyboard
diff --git a/Apple/testbed/iOSTestbed/app/README 
b/Platforms/Apple/testbed/iOSTestbed/app/README
similarity index 100%
rename from Apple/testbed/iOSTestbed/app/README
rename to Platforms/Apple/testbed/iOSTestbed/app/README
diff --git a/Apple/testbed/iOSTestbed/app_packages/README 
b/Platforms/Apple/testbed/iOSTestbed/app_packages/README
similarity index 100%
rename from Apple/testbed/iOSTestbed/app_packages/README
rename to Platforms/Apple/testbed/iOSTestbed/app_packages/README
diff --git a/Apple/testbed/iOSTestbed/iOSTestbed-Info.plist 
b/Platforms/Apple/testbed/iOSTestbed/iOSTestbed-Info.plist
similarity index 100%
rename from Apple/testbed/iOSTestbed/iOSTestbed-Info.plist
rename to Platforms/Apple/testbed/iOSTestbed/iOSTestbed-Info.plist
diff --git a/Apple/testbed/iOSTestbed/main.m 
b/Platforms/Apple/testbed/iOSTestbed/main.m
similarity index 100%
rename from Apple/testbed/iOSTestbed/main.m
rename to Platforms/Apple/testbed/iOSTestbed/main.m
diff --git a/configure b/configure
index 23f24d51c79e1a..c5109f69ebddb0 100755
--- a/configure
+++ b/configure
@@ -4389,7 +4389,7 @@ then :
        yes)
                case $ac_sys_system in
                        Darwin) enableval=/Library/Frameworks ;;
-                       iOS)    enableval=Apple/iOS/Frameworks/\$\(MULTIARCH\) 
;;
+                       iOS)    
enableval=Platforms/Apple/iOS/Frameworks/\$\(MULTIARCH\) ;;
                        *) as_fn_error $? "Unknown platform for framework 
build" "$LINENO" 5
                esac
        esac
@@ -4500,9 +4500,9 @@ then :
 
                                prefix=$PYTHONFRAMEWORKPREFIX
                                
PYTHONFRAMEWORKINSTALLNAMEPREFIX="@rpath/$PYTHONFRAMEWORKDIR"
-                               RESSRCDIR=Apple/iOS/Resources
+                               RESSRCDIR=Platforms/Apple/iOS/Resources
 
-                               ac_config_files="$ac_config_files 
Apple/iOS/Resources/Info.plist"
+                               ac_config_files="$ac_config_files 
Platforms/Apple/iOS/Resources/Info.plist"
 
                                ;;
                        *)
@@ -35618,7 +35618,7 @@ do
     "Mac/PythonLauncher/Makefile") CONFIG_FILES="$CONFIG_FILES 
Mac/PythonLauncher/Makefile" ;;
     "Mac/Resources/framework/Info.plist") CONFIG_FILES="$CONFIG_FILES 
Mac/Resources/framework/Info.plist" ;;
     "Mac/Resources/app/Info.plist") CONFIG_FILES="$CONFIG_FILES 
Mac/Resources/app/Info.plist" ;;
-    "Apple/iOS/Resources/Info.plist") CONFIG_FILES="$CONFIG_FILES 
Apple/iOS/Resources/Info.plist" ;;
+    "Platforms/Apple/iOS/Resources/Info.plist") CONFIG_FILES="$CONFIG_FILES 
Platforms/Apple/iOS/Resources/Info.plist" ;;
     "Makefile.pre") CONFIG_FILES="$CONFIG_FILES Makefile.pre" ;;
     "Misc/python.pc") CONFIG_FILES="$CONFIG_FILES Misc/python.pc" ;;
     "Misc/python-embed.pc") CONFIG_FILES="$CONFIG_FILES Misc/python-embed.pc" 
;;
diff --git a/configure.ac b/configure.ac
index 635fce3f2e6fad..8fae8b46fa6fd5 100644
--- a/configure.ac
+++ b/configure.ac
@@ -568,7 +568,7 @@ AC_ARG_ENABLE([framework],
        yes)
                case $ac_sys_system in
                        Darwin) enableval=/Library/Frameworks ;;
-                       iOS)    enableval=Apple/iOS/Frameworks/\$\(MULTIARCH\) 
;;
+                       iOS)    
enableval=Platforms/Apple/iOS/Frameworks/\$\(MULTIARCH\) ;;
                        *) AC_MSG_ERROR([Unknown platform for framework build])
                esac
        esac
@@ -675,9 +675,9 @@ AC_ARG_ENABLE([framework],
 
                                prefix=$PYTHONFRAMEWORKPREFIX
                                
PYTHONFRAMEWORKINSTALLNAMEPREFIX="@rpath/$PYTHONFRAMEWORKDIR"
-                               RESSRCDIR=Apple/iOS/Resources
+                               RESSRCDIR=Platforms/Apple/iOS/Resources
 
-                               
AC_CONFIG_FILES([Apple/iOS/Resources/Info.plist])
+                               
AC_CONFIG_FILES([Platforms/Apple/iOS/Resources/Info.plist])
                                ;;
                        *)
                                AC_MSG_ERROR([Unknown platform for framework 
build])

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to
diff --git a/Apple/__main__.py b/Platforms/Apple/__main__.py
similarity index 98%
rename from Apple/__main__.py
rename to Platforms/Apple/__main__.py
index c19108c8e389b5..c646a222bc630f 100644
--- a/Apple/__main__.py
+++ b/Platforms/Apple/__main__.py
@@ -10,7 +10,7 @@
 #
 # The simplest entry point is:
 #
 #   $ python Apple ci iOS
 #
 # which will:
 # * Clean any pre-existing build artefacts
@@ -57,7 +57,7 @@
 ArgsT = Sequence[str | Path]
 
 SCRIPT_NAME = Path(__file__).name
-PYTHON_DIR = Path(__file__).resolve().parent.parent
+PYTHON_DIR = Path(__file__).resolve().parent.parent.parent
 
 CROSS_BUILD_DIR = PYTHON_DIR / "cross-build"
 
@@ -140,7 +140,7 @@ def apple_env(host: str) -> EnvironmentT:
     """Construct an Apple development environment for the given host."""
     env = {
         "PATH": ":".join([
-            str(PYTHON_DIR / "Apple/iOS/Resources/bin"),
+            str(PYTHON_DIR / "Platforms/Apple/iOS/Resources/bin"),
             str(subdir(host) / "prefix"),
             "/usr/bin",
             "/bin",
@@ -440,7 +440,10 @@ def framework_path(host_triple: str, multiarch: str) -> 
Path:
     :param host_triple: The host triple (e.g., arm64-apple-ios-simulator)
     :param multiarch: The multiarch identifier (e.g., arm64-simulator)
     """
-    return CROSS_BUILD_DIR / f"{host_triple}/Apple/iOS/Frameworks/{multiarch}"
+    return (
+        CROSS_BUILD_DIR
+        / f"{host_triple}/Platforms/Apple/iOS/Frameworks/{multiarch}"
+    )
 
 
 def package_version(prefix_path: Path) -> str:
@@ -624,7 +627,7 @@ def create_xcframework(platform: str) -> str:
 
         # Copy in the cross-architecture pyconfig.h
         shutil.copy(
-            PYTHON_DIR / f"Apple/{platform}/Resources/pyconfig.h",
+            PYTHON_DIR / f"Platforms/Apple/{platform}/Resources/pyconfig.h",
             slice_framework / "Headers/pyconfig.h",
         )
 
@@ -661,7 +664,7 @@ def create_xcframework(platform: str) -> str:
             host_path = (
                 CROSS_BUILD_DIR
                 / host_triple
-                / "Apple/iOS/Frameworks"
+                / "Platforms/Apple/iOS/Frameworks"
                 / multiarch
             )
             host_framework = host_path / "Python.framework"
@@ -691,7 +694,7 @@ def create_xcframework(platform: str) -> str:
 
     print(" - build tools")
     shutil.copytree(
-        PYTHON_DIR / "Apple/testbed/Python.xcframework/build",
+        PYTHON_DIR / "Platforms/Apple/testbed/Python.xcframework/build",
         package_path / "Python.xcframework/build",
     )
 
@@ -711,7 +714,7 @@ def package(context: argparse.Namespace) -> None:
         print()
         run([
             sys.executable,
-            "Apple/testbed",
+            "Platforms/Apple/testbed",
             "clone",
             "--platform",
             context.platform,
@@ -806,13 +809,13 @@ def test(context: argparse.Namespace, host: str | None = 
None) -> None:  # noqa:
                 framework_path = (
                     CROSS_BUILD_DIR
                     / host
-                    / f"Apple/{context.platform}"
+                    / f"Platforms/Apple/{context.platform}"
                     / f"Frameworks/{apple_multiarch(host)}"
                 )
 
         run([
             sys.executable,
-            "Apple/testbed",
+            "Platforms/Apple/testbed",
             "clone",
             "--platform",
             context.platform,
@@ -10,7 +10,7 @@
 # The simplest entry point is:
 #
-#   $ python Apple ci iOS
+#   $ python Platforms/Apple ci iOS
 #
 # which will: